==> mingw-w64-clang-aarch64-qt6-declarative-6.6.3-1-any.pkg.tar.zst: clangarm64/lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmlcachegen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlcachegen )
list(APPEND _cmake_import_check_files_for_Qt6::qmlcachegen "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe" )

# Import target "Qt6::qmldom" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmldom PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmldom.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmldom )
list(APPEND _cmake_import_check_files_for_Qt6::qmldom "${_IMPORT_PREFIX}/bin/qmldom.exe" )

# Import target "Qt6::qmllint" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmllint )
list(APPEND _cmake_import_check_files_for_Qt6::qmllint "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe" )

# Import target "Qt6::qmltc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltc.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltc )
list(APPEND _cmake_import_check_files_for_Qt6::qmltc "${_IMPORT_PREFIX}/bin/qmltc.exe" )

# Import target "Qt6::qmltyperegistrar" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltyperegistrar )
list(APPEND _cmake_import_check_files_for_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe" )

# Import target "Qt6::qmlimportscanner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlimportscanner )
list(APPEND _cmake_import_check_files_for_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe" )

# Import target "Qt6::qmlformat" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlformat )
list(APPEND _cmake_import_check_files_for_Qt6::qmlformat "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe" )

# Import target "Qt6::qmlprofiler" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlprofiler )
list(APPEND _cmake_import_check_files_for_Qt6::qmlprofiler "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe" )

# Import target "Qt6::qmltime" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltime )
list(APPEND _cmake_import_check_files_for_Qt6::qmltime "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe" )

# Import target "Qt6::qmlplugindump" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlplugindump )
list(APPEND _cmake_import_check_files_for_Qt6::qmlplugindump "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe" )

# Import target "Qt6::qmltestrunner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::qmltestrunner "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-declarative-6.8.1-1-any.pkg.tar.zst: clangarm64/lib/cmake/Qt6QmlTools/Qt6QmlToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qmlaotstats" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlaotstats APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlaotstats PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmlaotstats.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlaotstats )
list(APPEND _cmake_import_check_files_for_Qt6::qmlaotstats "${_IMPORT_PREFIX}/share/qt6/bin/qmlaotstats.exe" )

# Import target "Qt6::qmlcachegen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlcachegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlcachegen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlcachegen )
list(APPEND _cmake_import_check_files_for_Qt6::qmlcachegen "${_IMPORT_PREFIX}/share/qt6/bin/qmlcachegen.exe" )

# Import target "Qt6::qmldom" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmldom PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmldom.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmldom )
list(APPEND _cmake_import_check_files_for_Qt6::qmldom "${_IMPORT_PREFIX}/bin/qmldom.exe" )

# Import target "Qt6::qmllint" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmllint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmllint PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmllint )
list(APPEND _cmake_import_check_files_for_Qt6::qmllint "${_IMPORT_PREFIX}/bin/qmllint-qt6.exe" )

# Import target "Qt6::qmltc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltc.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltc )
list(APPEND _cmake_import_check_files_for_Qt6::qmltc "${_IMPORT_PREFIX}/bin/qmltc.exe" )

# Import target "Qt6::qmltyperegistrar" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltyperegistrar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltyperegistrar PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltyperegistrar )
list(APPEND _cmake_import_check_files_for_Qt6::qmltyperegistrar "${_IMPORT_PREFIX}/share/qt6/bin/qmltyperegistrar.exe" )

# Import target "Qt6::qmljsrootgen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmljsrootgen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmljsrootgen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmljsrootgen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmljsrootgen )
list(APPEND _cmake_import_check_files_for_Qt6::qmljsrootgen "${_IMPORT_PREFIX}/share/qt6/bin/qmljsrootgen.exe" )

# Import target "Qt6::qmlimportscanner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlimportscanner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlimportscanner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlimportscanner )
list(APPEND _cmake_import_check_files_for_Qt6::qmlimportscanner "${_IMPORT_PREFIX}/share/qt6/bin/qmlimportscanner.exe" )

# Import target "Qt6::qmlformat" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlformat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlformat PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlformat )
list(APPEND _cmake_import_check_files_for_Qt6::qmlformat "${_IMPORT_PREFIX}/bin/qmlformat-qt6.exe" )

# Import target "Qt6::qmlprofiler" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlprofiler APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlprofiler PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlprofiler )
list(APPEND _cmake_import_check_files_for_Qt6::qmlprofiler "${_IMPORT_PREFIX}/bin/qmlprofiler-qt6.exe" )

# Import target "Qt6::qmltime" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltime PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltime )
list(APPEND _cmake_import_check_files_for_Qt6::qmltime "${_IMPORT_PREFIX}/bin/qmltime-qt6.exe" )

# Import target "Qt6::qmlplugindump" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmlplugindump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmlplugindump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmlplugindump )
list(APPEND _cmake_import_check_files_for_Qt6::qmlplugindump "${_IMPORT_PREFIX}/bin/qmlplugindump-qt6.exe" )

# Import target "Qt6::qmltestrunner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmltestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmltestrunner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::qmltestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::qmltestrunner "${_IMPORT_PREFIX}/bin/qmltestrunner-qt6.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
